/* copy.c */
int main(int, char *[]);

/* init.c */
int init(char *);

/* list.c */
int main(int, char *[]);
int parse(const char *);

/* remove.c */
int main(int, char *[]);

/* rename.c */
int main(int, char *[]);
